using Microsoft.Extensions.DependencyInjection;
using PrecastConcretePlantView;
using RenovationWorkBusinessLogic.BusinessLogic;
using RenovationWorkContracts.BusinessLogicsContracts;
using RenovationWorkContracts.StorageContracts;
using RenovationWorkListImplement.Implements;
using System;
using Microsoft.Extensions.Logging;
using NLog.Extensions.Logging;

namespace RenovationWorkView
{
    internal static class Program
    {
        private static ServiceProvider? _serviceProvider;
        public static ServiceProvider? ServiceProvider => _serviceProvider;

        [STAThread]
        static void Main()
        {
            ApplicationConfiguration.Initialize();
            var services = new ServiceCollection();
            ConfigureServices(services);
            _serviceProvider = services.BuildServiceProvider();
            Application.Run(_serviceProvider.GetRequiredService<FormMain>());
        }
        private static void ConfigureServices(ServiceCollection services)
        {
            services.AddLogging(option =>
            {
                option.SetMinimumLevel(LogLevel.Information);
                option.AddNLog("nlog.config");
            }); 
            services.AddTransient<IComponentStorage, ComponentStorage>();
            services.AddTransient<IOrderStorage, OrderStorage>();
            services.AddTransient<IRepairStorage, RepairStorage>();

            services.AddTransient<IComponentLogic, ComponentLogic>();
            services.AddTransient<IOrderLogic, OrderLogic>();
            services.AddTransient<IRepairLogic, RepairLogic>(); //

            services.AddTransient<FormMain>();
            services.AddTransient<FormComponent>();
            services.AddTransient<FormComponents>();
            services.AddTransient<FormCreateOrder>();
            services.AddTransient<FormRepair>();
            services.AddTransient<FormRepairComponent>();
            services.AddTransient<FormRepairs>(); //
        }
    }
}